#
# spec file for package libapparmor
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2011-2019 Christian Boltz
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libapparmor
Version:        2.13.6
Release:        1.24
Summary:        Utility library for AppArmor
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://launchpad.net/apparmor
Source0:        apparmor-%{version}.tar.gz
Source1:        apparmor-%{version}.tar.gz.asc
BuildRequires:  bison
BuildRequires:  dejagnu
BuildRequires:  flex
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package provides the libapparmor library, which contains the
change_hat(2) symbol, used for sub-process confinement by AppArmor, as
well as functions to parse AppArmor log messages.


%package -n libapparmor1
Summary:        Utility library for AppArmor
Group:          System/Libraries
%ifarch ppc64
Obsoletes:      libapparmor-64bit < 2.9
Provides:       libapparmor-64bit = %{version}
%endif
Provides:       libapparmor = %{version}
Obsoletes:      libapparmor < 2.9

%description -n libapparmor1
This package provides the libapparmor library, which contains the
change_hat(2) symbol, used for sub-process confinement by AppArmor, as
well as functions to parse AppArmor log messages.

%package -n libapparmor-devel
Summary:        Development headers and libraries for libapparmor
Group:          Development/Libraries/C and C++
Requires:       libapparmor1 = %{version}
Provides:       libapparmor:/usr/include/sys/apparmor.h

%description -n libapparmor-devel
These libraries are needed for developing software that makes use of the
AppArmor API.



%prep
%setup -q -n apparmor-%{version}

%build
%define _lto_cflags %{nil}
(
  cd ./libraries/libapparmor
  %configure \
  --without-perl \
  --without-python \
  --without-ruby \

  make
)

%check
make check -C libraries/libapparmor

%install
%makeinstall -C libraries/libapparmor
# create symlink for old change_hat(2) manpage
( cd %{buildroot}/%{_mandir}/man2/ && ln -s aa_change_hat.2 change_hat.2 )

# remove *.la and *.a files
rm -fv %{buildroot}%{_libdir}/libapparmor.la
rm -fv %{buildroot}%{_libdir}/libapparmor.a

%post -n libapparmor1 -p /sbin/ldconfig

%postun -n libapparmor1 -p /sbin/ldconfig

%files -n libapparmor1
%defattr(-,root,root)
%{_libdir}/libapparmor.so.*

%files -n libapparmor-devel
%defattr(-,root,root)
%{_libdir}/libapparmor.so
%{_libdir}/pkgconfig/libapparmor.pc
%doc %{_mandir}/man2/aa_change_hat.2.gz
%doc %{_mandir}/man2/aa_change_profile.2.gz
%doc %{_mandir}/man2/aa_stack_profile.2.gz
%doc %{_mandir}/man2/change_hat.2.gz
%doc %{_mandir}/man2/aa_find_mountpoint.2.gz
%doc %{_mandir}/man2/aa_getcon.2.gz
%doc %{_mandir}/man2/aa_query_label.2.gz
%doc %{_mandir}/man3/aa_features.3.gz
%doc %{_mandir}/man3/aa_kernel_interface.3.gz
%doc %{_mandir}/man3/aa_policy_cache.3.gz
%doc %{_mandir}/man3/aa_splitcon.3.gz
%dir %{_includedir}/aalogparse
%{_includedir}/sys/apparmor.h
%{_includedir}/sys/apparmor_private.h
%{_includedir}/aalogparse/*

%changelog
* Wed Dec  9 2020 suse-beta@cboltz.de
- update to AppArmor 2.13.6
  - see https://gitlab.com/apparmor/apparmor/-/wikis/Release_Notes_2.13.6
    for the detailed upstream changelog
- drop upstreamed patch libapparmor-so-number.diff
* Sat Oct 17 2020 suse-beta@cboltz.de
- update to AppArmor 2.13.5
  - fix two potential build failures
  - see https://gitlab.com/apparmor/apparmor/-/wikis/Release_Notes_2.13.5
    for the detailed upstream changelog
- add libapparmor-so-number.diff to fix libapparmor so version (!658)
* Thu Mar 12 2020 suse-beta@cboltz.de
- update to AppArmor 2.13.4
  - fix log parsing for logs with an embedded newline
  - see https://gitlab.com/apparmor/apparmor/-/wikis/Release_Notes_2.13.4
    for the detailed upstream changelog
* Tue Jun 18 2019 suse-beta@cboltz.de
- update to AppArmor 2.13.1
  - some fixes in cache handling
  - see https://gitlab.com/apparmor/apparmor/wikis/Release_Notes_2.13.3
    for the detailed upstream changelog
* Tue Apr 23 2019 mliska@suse.cz
- Disable LTO (boo#1133091).
* Fri Dec 21 2018 suse-beta@cboltz.de
- update to AppArmor 2.13.2
  - no changes in libapparmor
  - see https://gitlab.com/apparmor/apparmor/wikis/Release_Notes_2.13.2
    for the detailed upstream changelog
* Sun Oct 14 2018 suse-beta@cboltz.de
- update to AppArmor 2.13.1
  - several bug fixes
  - see https://gitlab.com/apparmor/apparmor/wikis/Release_Notes_2.13.1
    for the detailed upstream changelog
* Sun Apr 15 2018 suse-beta@cboltz.de
- update to AppArmor 2.13
  - add support for multiple cache directories and cache overlays
    (boo#1069906, boo#1074429)
  - see https://gitlab.com/apparmor/apparmor/wikis/Release_Notes_2.13
    for the detailed upstream changelog
* Mon Dec 25 2017 suse-beta@cboltz.de
- update to AppArmor 2.12
  - preserve errno across aa_*_unref() functions
  - see https://gitlab.com/apparmor/apparmor/wikis/Release_Notes_2.12
    for the detailed upstream changelog
- no longer package static libapparmor.a
* Tue Oct 31 2017 suse-beta@cboltz.de
- update to AppArmor 2.11.95 aka 2.12 beta1
  - no changes in libapparmor
  - see http://wiki.apparmor.net/index.php/ReleaseNotes_2_11_95
    for the detailed upstream changelog
* Wed Oct 25 2017 suse-beta@cboltz.de
- update to AppArmor 2.11.1
  - mostly test-related changes in libapparmor
  - see http://wiki.apparmor.net/index.php/ReleaseNotes_2_11_1 for
    upstream changelog
* Sat Feb 11 2017 jengelh@inai.de
- Fix RPM groups
* Sat Jan 28 2017 suse-beta@cboltz.de
- split libapparmor into separate spec to get rid of build loop
  involving mariadb, systemd, apparmor, libapr and mariadb again
  (see the discussion in SR 448871 for details)
- libapparmor.spec is based on the AppArmor 2.11 apparmor.spec, but
  with minimum BuildRequires
